<?php

namespace App\Http\Controllers;

use App\Models\InsuranceClaim;
use App\Models\ClaimAttachment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class InsuranceClaimController extends Controller
{
    public function store(Request $request)
    {
        $validated = $request->validate([
            'insureds_reference' => 'required|string',
            'capulus_reference' => 'required|string',
            'policy_number' => 'required|string',
            'insureds_name' => 'required|string',
            'company_address' => 'required|string',
            'company_postal_code' => 'required|string',
            'company_tel' => 'required|string',
            'subsidiary_depot' => 'nullable|string',
            'driver_name' => 'required|string',
            'occupation' => 'required|string',
            'employer_name' => 'required|string',
            'driver_address' => 'required|string',
            'driver_postal_code' => 'required|string',
            'driver_tel' => 'required|string',
            'driver_alternate_tel' => 'nullable|string',
            'driver_age' => 'required',
            'licence_type' => 'required|string',
            'licence_number' => 'required|string',
            'licence_years_held' => 'required',
            'has_convictions' => 'required',
            'registration_no' => 'required|string',
            'make' => 'required|string',
            'model' => 'required|string',
            'manufacture_year' => 'required|date',
            'value' => 'required|numeric',
            'owner_details' => 'nullable|string',
            'owner_postal_code' => 'nullable|string',
            'owner_tel' => 'nullable|string',
            'vehicle_location' => 'required|string',
            'vehicle_postal_code' => 'required|string',
            'vehicle_tel' => 'required|string',
            'claim_repair_under_policy' => 'required|boolean',
            'estimated_repair_cost' => 'required|numeric',
            'vehicle_status' => 'required|string',
            'damage_img1' => 'boolean',
            'damage_img2' => 'boolean',
            'damage_img3' => 'boolean',
            'damage_img4' => 'boolean',
            'damage_img5' => 'boolean',
            'damage_description' => 'required|string',
            'accident_date' => 'required|date',
            'accident_time' => 'required|string',
            'weather_condition' => 'required|string',
            'road_condition' => 'required|string',
            'accident_location' => 'required|string',
            'vehicle_lights' => 'required|string',
            'other_vehicle_lights' => 'required|string',
            'police_details' => 'nullable|string',
            'prosecution_details' => 'nullable|string',
            'speed_before_impact' => 'required|string',
            'speed_after_impact' => 'required|string',
            'horn_sounded' => 'required|boolean',
            'other_driver_name1' => 'nullable|string',
            'other_driver_postal1' => 'nullable|string',
            'other_driver_tel1' => 'nullable|string',
            'other_vehicle_make1' => 'nullable|string',
            'other_vehicle_model1' => 'nullable|string',
            'other_vehicle_reg1' => 'nullable|string',
            'other_vehicle_color1' => 'nullable|string',
            'other_vehicle_insurer1' => 'nullable|string',
            'other_vehicle_policy1' => 'nullable|string',
            'other_vehicle_damage1' => 'nullable|string',
            'other_vehicle_owner1' => 'nullable|string',
            'other_vehicle_occupants1' => 'nullable|string',
            'other_driver_name2' => 'nullable|string',
            'other_driver_postal2' => 'nullable|string',
            'other_driver_tel2' => 'nullable|string',
            'other_vehicle_make2' => 'nullable|string',
            'other_vehicle_model2' => 'nullable|string',
            'other_vehicle_reg2' => 'nullable|string',
            'other_vehicle_color2' => 'nullable|string',
            'other_vehicle_insurer2' => 'nullable|string',
            'other_vehicle_policy2' => 'nullable|string',
            'other_vehicle_damage2' => 'nullable|string',
            'other_vehicle_owner2' => 'nullable|string',
            'other_vehicle_occupants2' => 'nullable|string',
            'injured_name1' => 'nullable|string',
            'injured_postal1' => 'nullable|string',
            'injured_tel1' => 'nullable|string',
            'injuries1' => 'nullable|string',
            'injured_vehicle1' => 'nullable|string',
            'treatment1' => 'nullable|string',
            'hospital1' => 'nullable|string',
            'detained1' => 'nullable|string',
            'injured_name2' => 'nullable|string',
            'injured_postal2' => 'nullable|string',
            'injured_tel2' => 'nullable|string',
            'injuries2' => 'nullable|string',
            'injured_vehicle2' => 'nullable|string',
            'treatment2' => 'nullable|string',
            'hospital2' => 'nullable|string',
            'detained2' => 'nullable|string',
            'witness_name1' => 'nullable|string',
            'witness_address1' => 'nullable|string',
            'witness_in_vehicle1' => 'nullable|boolean',
            'witness_postcode1' => 'nullable|string',
            'witness_tel1' => 'nullable|string',
            'witness_name2' => 'nullable|string',
            'witness_address2' => 'nullable|string',
            'witness_in_vehicle2' => 'nullable|boolean',
            'witness_postcode2' => 'nullable|string',
            'witness_tel2' => 'nullable|string',
            'accident_plan' => 'required|string',
            'accident_circumstances' => 'required|string',
            'signing_driver_name' => 'required|string',
            'geo_stamp_location' => 'nullable|string',
            'digital_signature' => 'required|string',
            'declaration' => 'required|accepted'
        ]);

        // Set initial status as logged
        $validated['status'] = InsuranceClaim::STATUS_LOGGED;

        $claim = InsuranceClaim::create($validated);

        // Handle image uploads
        if ($request->hasFile('images')) {
            foreach ($request->file('images') as $image) {
                $path = $image->store('claim-images', 'public');

                $claim->attachments()->create([
                    'file_path' => $path,
                    'file_type' => 'image',
                    'original_name' => $image->getClientOriginalName(),
                    'mime_type' => $image->getMimeType(),
                    'file_size' => $image->getSize()
                ]);
            }
        }

        // Handle video uploads
        if ($request->hasFile('videos')) {
            foreach ($request->file('videos') as $video) {
                $path = $video->store('claim-videos', 'public');

                $claim->attachments()->create([
                    'file_path' => $path,
                    'file_type' => 'video',
                    'original_name' => $video->getClientOriginalName(),
                    'mime_type' => $video->getMimeType(),
                    'file_size' => $video->getSize()
                ]);
            }
        }

        dd($validated);
        return redirect()->route('main.index')->with('success', 'Claim submitted successfully.');
    }
}
