<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use App\Models\ClaimAttachment;
use App\Models\User;

class InsuranceClaim extends Model
{
    // Status Constants
    const STATUS_LOGGED = 'logged';
    const STATUS_OPEN = 'open';
    const STATUS_CLOSED = 'closed';

    protected $fillable = [
        'insureds_reference',
        'capulus_reference',
        'policy_number',
        'insureds_name',
        'company_address',
        'company_postal_code',
        'company_tel',
        'subsidiary_depot',
        'driver_name',
        'occupation',
        'employer_name',
        'driver_address',
        'driver_postal_code',
        'driver_tel',
        'driver_alternate_tel',
        'driver_age',
        'licence_type',
        'licence_number',
        'licence_years_held',
        'has_convictions',
        'registration_no',
        'make',
        'model',
        'manufacture_year',
        'value',
        'owner_details',
        'owner_postal_code',
        'owner_tel',
        'vehicle_location',
        'vehicle_postal_code',
        'vehicle_tel',
        'claim_repair_under_policy',
        'estimated_repair_cost',
        'vehicle_status',
        'damage_img1',
        'damage_img2',
        'damage_img3',
        'damage_img4',
        'damage_img5',
        'damage_description',
        'accident_date',
        'accident_time',
        'weather_condition',
        'road_condition',
        'accident_location',
        'vehicle_lights',
        'other_vehicle_lights',
        'police_details',
        'prosecution_details',
        'speed_before_impact',
        'speed_after_impact',
        'horn_sounded',
        'other_driver_name1',
        'other_driver_postal1',
        'other_driver_tel1',
        'other_vehicle_make1',
        'other_vehicle_model1',
        'other_vehicle_reg1',
        'other_vehicle_color1',
        'other_vehicle_insurer1',
        'other_vehicle_policy1',
        'other_vehicle_damage1',
        'other_vehicle_owner1',
        'other_vehicle_occupants1',
        'other_driver_name2',
        'other_driver_postal2',
        'other_driver_tel2',
        'other_vehicle_make2',
        'other_vehicle_model2',
        'other_vehicle_reg2',
        'other_vehicle_color2',
        'other_vehicle_insurer2',
        'other_vehicle_policy2',
        'other_vehicle_damage2',
        'other_vehicle_owner2',
        'other_vehicle_occupants2',
        'injured_name1',
        'injured_postal1',
        'injured_tel1',
        'injuries1',
        'injured_vehicle1',
        'treatment1',
        'hospital1',
        'detained1',
        'injured_name2',
        'injured_postal2',
        'injured_tel2',
        'injuries2',
        'injured_vehicle2',
        'treatment2',
        'hospital2',
        'detained2',
        'witness_name1',
        'witness_address1',
        'witness_in_vehicle1',
        'witness_postcode1',
        'witness_tel1',
        'witness_name2',
        'witness_address2',
        'witness_in_vehicle2',
        'witness_postcode2',
        'witness_tel2',
        'accident_plan',
        'accident_circumstances',
        'images',
        'videos',
        'signing_driver_name',
        'geo_stamp_location',
        'digital_signature',
        'declaration',
        'status',
        'close_status',
        'reopen',
        'user_id'
    ];

    protected $casts = [
        'claim_repair_under_policy' => 'boolean',
        'damage_img1' => 'boolean',
        'damage_img2' => 'boolean',
        'damage_img3' => 'boolean',
        'damage_img4' => 'boolean',
        'damage_img5' => 'boolean',
        'horn_sounded' => 'boolean',
        'witness_in_vehicle1' => 'boolean',
        'witness_in_vehicle2' => 'boolean',
        'declaration' => 'boolean',
        'reopen' => 'boolean',
        'value' => 'decimal:2',
        'estimated_repair_cost' => 'decimal:2',
        'manufacture_year' => 'date'
    ];

    public function attachments()
    {
        return $this->hasMany(ClaimAttachment::class, 'insurance_claim_id');
    }

    public function images()
    {
        return $this->hasMany(ClaimAttachment::class)->where('file_type', 'image');
    }

    public function videos()
    {
        return $this->hasMany(ClaimAttachment::class)->where('file_type', 'video');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
}
