<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    public function up()
    {
        Schema::create('insurance_claims', function (Blueprint $table) {
            $table->id();
            
            // Insured Company Details
            $table->string('insureds_reference');
            $table->string('capulus_reference');
            $table->string('policy_number');
            $table->string('insureds_name');
            $table->text('company_address');
            $table->string('company_postal_code');
            $table->string('company_tel');
            $table->string('subsidiary_depot')->nullable();
            
            // Driver Details
            $table->string('driver_name');
            $table->string('occupation');
            $table->string('employer_name');
            $table->text('driver_address');
            $table->string('driver_postal_code');
            $table->string('driver_tel');
            $table->string('driver_alternate_tel')->nullable();
            $table->integer('driver_age');
            $table->string('licence_type');
            $table->string('licence_number');
            $table->integer('licence_years_held');
            $table->boolean('has_convictions');
            
            // Vehicle Details
            $table->string('registration_no');
            $table->string('make');
            $table->string('model');
            $table->date('manufacture_year');
            $table->decimal('value', 10, 2);
            $table->text('owner_details')->nullable();
            $table->string('owner_postal_code')->nullable();
            $table->string('owner_tel')->nullable();
            $table->text('vehicle_location');
            $table->string('vehicle_postal_code');
            $table->string('vehicle_tel');
            $table->boolean('claim_repair_under_policy');
            $table->decimal('estimated_repair_cost', 10, 2);
            $table->string('vehicle_status');
            
            // Damage Details
            $table->boolean('damage_img1')->default(false);
            $table->boolean('damage_img2')->default(false);
            $table->boolean('damage_img3')->default(false);
            $table->boolean('damage_img4')->default(false);
            $table->boolean('damage_img5')->default(false);
            $table->text('damage_description')->nullable();
            
            // Accident Details
            $table->date('accident_date');
            $table->time('accident_time');
            $table->string('weather_condition');
            $table->string('road_condition');
            $table->text('accident_location');
            $table->string('vehicle_lights');
            $table->string('other_vehicle_lights');
            $table->string('police_details')->nullable();
            $table->text('prosecution_details')->nullable();
            $table->string('speed_before_impact');
            $table->string('speed_after_impact');
            $table->boolean('horn_sounded');
            
            // Other Vehicle Details 1
            $table->string('other_driver_name1')->nullable();
            $table->string('other_driver_postal1')->nullable();
            $table->string('other_driver_tel1')->nullable();
            $table->string('other_vehicle_make1')->nullable();
            $table->string('other_vehicle_model1')->nullable();
            $table->string('other_vehicle_reg1')->nullable();
            $table->string('other_vehicle_color1')->nullable();
            $table->string('other_vehicle_insurer1')->nullable();
            $table->string('other_vehicle_policy1')->nullable();
            $table->text('other_vehicle_damage1')->nullable();
            $table->string('other_vehicle_owner1')->nullable();
            $table->integer('other_vehicle_occupants1')->nullable();
            
            // Other Vehicle Details 2
            $table->string('other_driver_name2')->nullable();
            $table->string('other_driver_postal2')->nullable();
            $table->string('other_driver_tel2')->nullable();
            $table->string('other_vehicle_make2')->nullable();
            $table->string('other_vehicle_model2')->nullable();
            $table->string('other_vehicle_reg2')->nullable();
            $table->string('other_vehicle_color2')->nullable();
            $table->string('other_vehicle_insurer2')->nullable();
            $table->string('other_vehicle_policy2')->nullable();
            $table->text('other_vehicle_damage2')->nullable();
            $table->string('other_vehicle_owner2')->nullable();
            $table->integer('other_vehicle_occupants2')->nullable();
            
            // Injured Persons Details
            $table->string('injured_name1')->nullable();
            $table->string('injured_postal1')->nullable();
            $table->string('injured_tel1')->nullable();
            $table->string('injured_vehicle1')->nullable();
            $table->text('injured_details1')->nullable();
            
            // Signing Declaration
            $table->string('signing_driver_name');
            $table->string('geo_stamp_location');
            $table->string('digital_signature');
            $table->boolean('declaration')->default(false);
            
            // Status fields
            $table->string('status')->default('pending'); 
            $table->string('close_status')->nullable();
            $table->boolean('reopen')->default(0)->nullable();
            
            $table->timestamps();
        });
    }

    public function down()
    {
        Schema::dropIfExists('insurance_claims');
    }
};
