<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>Case Details</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            color: #333;
            margin: 20px;
        }
        .header {
            text-align: center;
            margin-bottom: 30px;
            border-bottom: 2px solid #333;
            padding-bottom: 10px;
        }
        .section {
            margin-bottom: 30px;
        }
        .section-title {
            background-color: #f4f4f4;
            padding: 8px 15px;
            font-weight: bold;
            margin-bottom: 15px;
            font-size: 16px;
        }
        .info-row {
            margin-bottom: 8px;
            padding: 0 15px;
        }
        .label {
            font-weight: bold;
            display: inline-block;
            width: 250px;
            vertical-align: top;
        }
        .value {
            display: inline-block;
            max-width: 400px;
        }
        .footer {
            text-align: center;
            margin-top: 30px;
            font-size: 12px;
            border-top: 1px solid #333;
            padding-top: 10px;
        }
        .page-break {
            page-break-after: always;
        }
    </style>
</head>
<body>
    <div class="header">
        <h1>Insurance Claim Details</h1>
        <p>Generated on: {{ now()->format('d/m/Y H:i:s') }}</p>
    </div>

    <div class="section">
        <div class="section-title">Details of Insured Company</div>
        <div class="info-row">
            <span class="label">Insured's Reference:</span>
            <span class="value">{{ $case->insureds_reference }}</span>
        </div>
        <div class="info-row">
            <span class="label">Capulus Reference:</span>
            <span class="value">{{ $case->capulus_reference }}</span>
        </div>
        <div class="info-row">
            <span class="label">Policy Number:</span>
            <span class="value">{{ $case->policy_number }}</span>
        </div>
        <div class="info-row">
            <span class="label">Subsidiary or Depot:</span>
            <span class="value">{{ $case->subsidiary_depot }}</span>
        </div>
    </div>

    <div class="section">
        <div class="section-title">Details of Insured Driver</div>
        <div class="info-row">
            <span class="label">Name:</span>
            <span class="value">{{ $case->driver_name }}</span>
        </div>
        <div class="info-row">
            <span class="label">Contact Number:</span>
            <span class="value">{{ $case->driver_contact }}</span>
        </div>
        <div class="info-row">
            <span class="label">Email:</span>
            <span class="value">{{ $case->driver_email }}</span>
        </div>
        <div class="info-row">
            <span class="label">Licence Type:</span>
            <span class="value">{{ $case->licence_type }}</span>
        </div>
    </div>

    <div class="section">
        <div class="section-title">Details of Insured Vehicle</div>
        <div class="info-row">
            <span class="label">Registration Number:</span>
            <span class="value">{{ $case->registration_no }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Make:</span>
            <span class="value">{{ $case->vehicle_make }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Model:</span>
            <span class="value">{{ $case->vehicle_model }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Type:</span>
            <span class="value">{{ $case->vehicle_type }}</span>
        </div>
        <div class="info-row">
            <span class="label">Telephone Number:</span>
            <span class="value">{{ $case->vehicle_tel }}</span>
        </div>
    </div>

    <div class="section">
        <div class="section-title">Details of Accident</div>
        <div class="info-row">
            <span class="label">Date:</span>
            <span class="value">{{ $case->accident_date ? \Carbon\Carbon::parse($case->accident_date)->format('d/m/Y') : '' }}</span>
        </div>
        <div class="info-row">
            <span class="label">Time:</span>
            <span class="value">{{ $case->accident_time }}</span>
        </div>
        <div class="info-row">
            <span class="label">Location:</span>
            <span class="value">{{ $case->accident_location }}</span>
        </div>
        <div class="info-row">
            <span class="label">Speed Before Impact:</span>
            <span class="value">{{ $case->speed_before_impact }}</span>
        </div>
        <div class="info-row">
            <span class="label">Speed At Impact:</span>
            <span class="value">{{ $case->speed_at_impact }}</span>
        </div>
        <div class="info-row">
            <span class="label">Point of Impact:</span>
            <span class="value">{{ $case->point_of_impact }}</span>
        </div>
    </div>

    <div class="section">
        <div class="section-title">Details of Other Vehicles Involved / Property Damaged</div>
        <div class="info-row">
            <span class="label">Driver 1 Name and Address:</span>
            <span class="value">{{ $case->other_driver_name1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Owner 1:</span>
            <span class="value">{{ $case->other_vehicle_owner1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Registration 1:</span>
            <span class="value">{{ $case->other_vehicle_reg1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Insurance Company 1:</span>
            <span class="value">{{ $case->other_vehicle_insurer1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Policy Number 1:</span>
            <span class="value">{{ $case->other_vehicle_policy1 }}</span>
        </div>

        @if($case->other_driver_name2)
        <div class="info-row" style="margin-top: 15px;">
            <span class="label">Driver 2 Name and Address:</span>
            <span class="value">{{ $case->other_driver_name2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Owner 2:</span>
            <span class="value">{{ $case->other_vehicle_owner2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Registration 2:</span>
            <span class="value">{{ $case->other_vehicle_reg2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Insurance Company 2:</span>
            <span class="value">{{ $case->other_vehicle_insurer2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Policy Number 2:</span>
            <span class="value">{{ $case->other_vehicle_policy2 }}</span>
        </div>
        @endif
    </div>

    <div class="section">
        <div class="section-title">Details of Persons Injured</div>
        <div class="info-row">
            <span class="label">Person 1 Name:</span>
            <span class="value">{{ $case->injured_name1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Person 1 Address:</span>
            <span class="value">{{ $case->injured_address1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Person 1 Telephone:</span>
            <span class="value">{{ $case->injured_tel1 }}</span>
        </div>

        @if($case->injured_name2)
        <div class="info-row" style="margin-top: 15px;">
            <span class="label">Person 2 Name:</span>
            <span class="value">{{ $case->injured_name2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Person 2 Address:</span>
            <span class="value">{{ $case->injured_address2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Person 2 Telephone:</span>
            <span class="value">{{ $case->injured_tel2 }}</span>
        </div>
        @endif
    </div>

    <div class="section">
        <div class="section-title">Witnesses</div>
        <div class="info-row">
            <span class="label">Witness 1 Name:</span>
            <span class="value">{{ $case->witness_name1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Witness 1 Address:</span>
            <span class="value">{{ $case->witness_address1 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Witness 1 Telephone:</span>
            <span class="value">{{ $case->witness_tel1 }}</span>
        </div>

        @if($case->witness_name2)
        <div class="info-row" style="margin-top: 15px;">
            <span class="label">Witness 2 Name:</span>
            <span class="value">{{ $case->witness_name2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Witness 2 Address:</span>
            <span class="value">{{ $case->witness_address2 }}</span>
        </div>
        <div class="info-row">
            <span class="label">Witness 2 Telephone:</span>
            <span class="value">{{ $case->witness_tel2 }}</span>
        </div>
        @endif
    </div>

    <div class="section">
        <div class="section-title">Circumstances of Accident</div>
        <div class="info-row">
            <span class="label">Circumstances:</span>
            <span class="value">{{ $case->circumstances }}</span>
        </div>
    </div>

    @if($additionalInfo)
    <div class="section">
        <div class="section-title">Additional Information</div>
        <div class="info-row">
            <span class="label">Policy Number:</span>
            <span class="value">{{ $additionalInfo->policy_number }}</span>
        </div>
        <div class="info-row">
            <span class="label">Claim Number:</span>
            <span class="value">{{ $additionalInfo->claim_number }}</span>
        </div>
        <div class="info-row">
            <span class="label">Incident Date:</span>
            <span class="value">{{ $additionalInfo->incident_date->format('d/m/Y') }}</span>
        </div>
        <div class="info-row">
            <span class="label">Notified Date:</span>
            <span class="value">{{ $additionalInfo->notified_date->format('d/m/Y') }}</span>
        </div>
        <div class="info-row">
            <span class="label">Driver Age:</span>
            <span class="value">{{ $additionalInfo->driver_age }}</span>
        </div>
        <div class="info-row">
            <span class="label">Claim Notified By:</span>
            <span class="value">{{ $additionalInfo->claim_notified_by }}</span>
        </div>
        <div class="info-row">
            <span class="label">Vehicle Registration:</span>
            <span class="value">{{ $additionalInfo->vehicle_registration }}</span>
        </div>
        <div class="info-row">
            <span class="label">File Handler:</span>
            <span class="value">{{ $additionalInfo->file_handler }}</span>
        </div>
        <div class="info-row">
            <span class="label">Responsibility:</span>
            <span class="value">{{ $additionalInfo->responsibility }}</span>
        </div>
        <div class="info-row">
            <span class="label">Circumstances:</span>
            <span class="value">{{ $additionalInfo->circumstances }}</span>
        </div>
    </div>
    @endif

    @if($caseClosure)
    <div class="section">
        <div class="section-title">Closure Information</div>
        <div class="info-row">
            <span class="label">Closure Date:</span>
            <span class="value">{{ $caseClosure->created_at->format('d/m/Y H:i:s') }}</span>
        </div>
        <div class="info-row">
            <span class="label">Closed By:</span>
            <span class="value">{{ $caseClosure->user->name }}</span>
        </div>
        <div class="info-row">
            <span class="label">Closure Notes:</span>
            <span class="value">{{ $caseClosure->notes }}</span>
        </div>
    </div>
    @endif

    <div class="footer">
        <p>This document was automatically generated by the Insurance Claims Management System</p>
        <p>Generated Date: {{ now()->format('d/m/Y H:i:s') }}</p>
    </div>
</body>
</html>
